Date: 07 12, 2001 12:26:49 PM

Viewing Intermediate Trees

You can select a specific pass in the analyzer sequence and view the cumulative parse tree for that pass. This is helpful when you want to see how the each pass in the analyzer sequence is operating.

To view an intermediate parse tree:

1. In the Ana Tab, select the pass in the analyzer sequence.

2. Right-click and select View > Entire Tree.

Note: To view intermediate parse trees, you must run the analyzer with the Generate Logs button on.

Tip: You can also select the pass and click on the View Parse Tree button in the Debug Toolbar.

## See Also

Viewing Parse Trees

Viewing Concept Trees

Viewing Partial Trees

Viewing Parse Tree Matches

Viewing Final Trees